@@ -65,7 +65,7 @@ impl<'a> Iterator for Columns<'a> {
         self.iter.next().map(|p| {
             let s = &self.line[self.pos..*p];
             self.pos = *p + 1;
-            if s.starts_with("\"") { &s[1..s.len() - 1] } else { s }
+            if s.starts_with('\"') { &s[1..s.len() - 1] } else { s }
         })
     }
 
@@ -87,7 +87,7 @@ impl<'a> Columns<'a> {
     pub fn new(line: &'a str, cols: &'a [usize]) -> Columns<'a> {
         Columns {
             pos: 0,
-            line: &line,
+            line: line,
             iter: cols.iter(),
         }
     }
@@ -95,11 +95,11 @@ impl<'a> Columns<'a> {
     fn peek(&self) -> Option<&'a str> {
         self.iter.clone().next().map(|p| {
             let s = &self.line[self.pos..*p];
-            if s.starts_with("\"") { &s[1..s.len() - 1] } else { s }
+            if s.starts_with('\"') { &s[1..s.len() - 1] } else { s }
         })
     }
 
-    fn from_str<T>(&mut self) -> Result<T>
+    fn next_str<T>(&mut self) -> Result<T>
         where T: FromStr + ::std::fmt::Debug, 
               T::Err: ::std::fmt::Debug
     {
@@ -123,19 +123,19 @@ impl<'a> serialize::Decoder for Columns<'a> {
         Error::Decode(err.into())
     }
     fn read_nil(&mut self) -> Result<()> { unimplemented!() }
-    fn read_usize(&mut self) -> Result<usize> { self.from_str() }
-    fn read_u64(&mut self) -> Result<u64> { self.from_str() }
-    fn read_u32(&mut self) -> Result<u32> { self.from_str() }
-    fn read_u16(&mut self) -> Result<u16> { self.from_str() }
-    fn read_u8(&mut self) -> Result<u8> { self.from_str() }
-    fn read_isize(&mut self) -> Result<isize> { self.from_str() }
-    fn read_i64(&mut self) -> Result<i64> { self.from_str() }
-    fn read_i32(&mut self) -> Result<i32> { self.from_str() }
-    fn read_i16(&mut self) -> Result<i16> { self.from_str() }
-    fn read_i8(&mut self) -> Result<i8> { self.from_str() }
-    fn read_bool(&mut self) -> Result<bool> { self.from_str() }
-    fn read_f64(&mut self) -> Result<f64> { self.from_str() }
-    fn read_f32(&mut self) -> Result<f32> { self.from_str() }
+    fn read_usize(&mut self) -> Result<usize> { self.next_str() }
+    fn read_u64(&mut self) -> Result<u64> { self.next_str() }
+    fn read_u32(&mut self) -> Result<u32> { self.next_str() }
+    fn read_u16(&mut self) -> Result<u16> { self.next_str() }
+    fn read_u8(&mut self) -> Result<u8> { self.next_str() }
+    fn read_isize(&mut self) -> Result<isize> { self.next_str() }
+    fn read_i64(&mut self) -> Result<i64> { self.next_str() }
+    fn read_i32(&mut self) -> Result<i32> { self.next_str() }
+    fn read_i16(&mut self) -> Result<i16> { self.next_str() }
+    fn read_i8(&mut self) -> Result<i8> { self.next_str() }
+    fn read_bool(&mut self) -> Result<bool> { self.next_str() }
+    fn read_f64(&mut self) -> Result<f64> { self.next_str() }
+    fn read_f32(&mut self) -> Result<f32> { self.next_str() }
     fn read_char(&mut self) -> Result<char> {
         let col = try!(self.next().ok_or(Error::EOL));
         if col.len() != 1 {
@@ -144,7 +144,7 @@ impl<'a> serialize::Decoder for Columns<'a> {
         }
         Ok(col.chars().next().unwrap())
     }
-    fn read_str(&mut self) -> Result<String> { self.from_str() }
+    fn read_str(&mut self) -> Result<String> { self.next_str() }
     fn read_enum<T, F>(&mut self, _: &str, f: F) -> Result<T>
             where F: FnOnce(&mut Columns<'a>) -> Result<T> {
         f(self)
