@@ -57,7 +57,7 @@ pub mod error;
 
 use self::columns::{Columns, BytesColumns};
 use std::fs::File;
-use std::io::{self, BufRead, BufReader, Write};
+use std::io::{self, BufRead, BufReader};
 use std::iter::Iterator;
 use std::path::Path;
 
@@ -66,6 +66,8 @@ use rustc_serialize::Decodable;
 
 #[cfg(test)] mod test;
 
+const UTF8_BOM: &'static [u8] = b"\xef\xbb\xbf";
+
 /// Csv reader
 /// 
 /// Iterates over the rows of the csv
@@ -116,7 +118,9 @@ impl<B: BufRead> Csv<B> {
     /// Creates a Csv from a generic BufReader
     /// 
     /// Note: default delimiter = ','
-    pub fn from_reader(reader: B) -> Csv<B> {
+    pub fn from_reader(mut reader: B) -> Csv<B> {
+        let result = try_consume_utf8_bom(&mut reader);
+
         Csv {
             reader: reader,
             delimiter: b',',
@@ -124,7 +128,7 @@ impl<B: BufRead> Csv<B> {
             headers: None,
             flexible: false,
             len: None,
-            exit: false,
+            exit: result.is_err(),
             current_line: 0,
         }
     }
@@ -290,7 +294,7 @@ macro_rules! consume_quote {
                     match $bytes.clone().next() {
                         Some((i, &b'\"')) => {
                             $bytes.next(); // escaping quote
-                            let _ = $buf.write(&$available[$start..i]);
+                            $buf.extend_from_slice(&$available[$start..i]);
                             $start = i + 1;
                             $quote_count += 1;
                         },
@@ -309,8 +313,9 @@ macro_rules! consume_quote {
     }
 }
 
+/// Reads an entire line into memory
 fn read_line<R: BufRead>(r: &mut R, buf: &mut Vec<u8>,
-    delimiter: u8, cols: &mut Vec<usize>) -> Result<usize>
+                         delimiter: u8, cols: &mut Vec<usize>) -> Result<usize>
 {
     let mut read = 0;
     let mut in_quote = false;
@@ -324,7 +329,7 @@ fn read_line<R: BufRead>(r: &mut R, buf: &mut Vec<u8>,
                 Err(ref e) if e.kind() == io::ErrorKind::Interrupted => continue,
                 Err(e) => return Err(Error::from(e)),
             };
-            
+
             let mut bytes = available.iter().enumerate();
             let mut start = 0;
 
@@ -347,7 +352,7 @@ fn read_line<R: BufRead>(r: &mut R, buf: &mut Vec<u8>,
                     Some((i, &b'\n')) => {
                         done = true;
                         used = i + 1;
-                        let _ = buf.write(&available[start..i]);
+                        buf.extend_from_slice(&available[start..i]);
                         break;
                     },
                     Some((i, &d)) => {
@@ -355,7 +360,7 @@ fn read_line<R: BufRead>(r: &mut R, buf: &mut Vec<u8>,
                     },
                     None => {
                         used = available.len();
-                        let _ = buf.write(&available[start..used]);
+                        buf.extend_from_slice(&available[start..used]);
                         break;
                     },
                 }
@@ -367,3 +372,11 @@ fn read_line<R: BufRead>(r: &mut R, buf: &mut Vec<u8>,
     }
     Ok(read)
 }
+
+fn try_consume_utf8_bom<B: BufRead>(reader: &mut B) -> Result<()> {
+    if try!(reader.fill_buf()).starts_with(UTF8_BOM) {
+        reader.consume(UTF8_BOM.len());
+    }
+
+    Ok(())
+}
